View source: R/addDemographicsQuery.R
| addDateOfBirthQuery | R Documentation |
Same as addDateOfBirth(), except query is not computed to a table.
addDateOfBirthQuery(
x,
dateOfBirthName = "date_of_birth",
missingDay = 1,
missingMonth = 1,
imposeDay = FALSE,
imposeMonth = FALSE
)
x |
A table containing individuals in a CDM reference. |
dateOfBirthName |
Name of the date-of-birth column to add. |
missingDay |
Day of the month assigned when day of birth is missing. |
missingMonth |
Month of the year assigned when month of birth is missing. |
imposeDay |
If |
imposeMonth |
If |
The function returns the table x with an extra column that contains the date of birth.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addDateOfBirthQuery()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.