| addDeathDate | R Documentation |
indexDate will be observed.Add date of death for individuals. Only death within the same observation
period than indexDate will be observed.
addDeathDate(
x,
indexDate = "cohort_start_date",
censorDate = NULL,
window = c(0, Inf),
deathDateName = "date_of_death",
name = NULL
)
x |
A table containing individuals in a CDM reference. |
indexDate |
Name of a date column in |
censorDate |
Date or name of a date column in |
window |
Window or windows of time relative to |
deathDateName |
name of the new column to be added. |
name |
Name of the new table. If |
table x with the added column with death information added.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addDeathDate()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.