| addDeathDays | R Documentation |
indexDate will be observed.Add days to death for individuals. Only death within the same observation
period than indexDate will be observed.
addDeathDays(
x,
indexDate = "cohort_start_date",
censorDate = NULL,
window = c(0, Inf),
deathDaysName = "days_to_death",
name = NULL,
type = "numeric"
)
x |
A table containing individuals in a CDM reference. |
indexDate |
Name of a date column in |
censorDate |
Date or name of a date column in |
window |
Window or windows of time relative to |
deathDaysName |
name of the new column to be added. |
name |
Name of the new table. If |
type |
Type of the created column(s). Counts, days, age, and observation
durations can be |
table x with the added column with death information added.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addDeathDays()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.