View source: R/addDemographics.R
| addFutureObservation | R Documentation |
Compute the number of days till the end of the observation period at a certain date
addFutureObservation(
x,
indexDate = "cohort_start_date",
futureObservationName = "future_observation",
futureObservationType = "days",
name = NULL,
type = "numeric"
)
x |
A table containing individuals in a CDM reference. |
indexDate |
Name of a date column in |
futureObservationName |
Name of the future-observation column to add. |
futureObservationType |
Whether to return a |
name |
Name of the new table. If |
type |
Type of the created column(s). Counts, days, age, and observation
durations can be |
cohort table with added column containing future observation of the individuals.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addFutureObservation()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.