filterCohortId: Filter a cohort according to cohort_definition_id column, the...

View source: R/filterCohortId.R

filterCohortIdR Documentation

Filter a cohort according to cohort_definition_id column, the result is not computed into a table. only a query is added. Used usually as internal functions of other packages.

Description

Filter a cohort according to cohort_definition_id column, the result is not computed into a table. only a query is added. Used usually as internal functions of other packages.

Usage

filterCohortId(cohort, cohortId = NULL)

Arguments

cohort

A cohort_table object.

cohortId

A vector with cohort ids.

Value

A cohort_table object.


PatientProfiles documentation built on Feb. 24, 2026, 5:10 p.m.