filterInObservation: Filter the rows of a 'cdm_table' to the ones in observation...

View source: R/filterInObservation.R

filterInObservationR Documentation

Filter the rows of a cdm_table to the ones in observation that indexDate is in observation.

Description

Filter the rows of a cdm_table to the ones in observation that indexDate is in observation.

Usage

filterInObservation(x, indexDate)

Arguments

x

A cdm_table object.

indexDate

Name of a column of x that is a date.

Value

A cdm_table that is a subset of the original table.

Examples

## Not run: 
library(PatientProfiles)
library(omock)

cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")

cdm$condition_occurrence |>
  filterInObservation(indexDate = "condition_start_date")


## End(Not run)


PatientProfiles documentation built on Feb. 24, 2026, 5:10 p.m.