targetEndDateDoc: Helper for consistent documentation of 'targetEndDate'.

targetEndDateDocR Documentation

Helper for consistent documentation of targetEndDate.

Description

Helper for consistent documentation of targetEndDate.

Arguments

targetEndDate

Name or names of end-date columns in the target tables to use for the intersection. If NULL, the target is treated as a point event.


PatientProfiles documentation built on Aug. 22, 2026, 1:07 a.m.