typeDoc: Helper for consistent documentation of 'type'.

typeDocR Documentation

Helper for consistent documentation of type.

Description

Helper for consistent documentation of type.

Arguments

type

Type of the created column(s). Counts, days, age, and observation durations can be "numeric" or "integer". Flag columns can also be "logical". Field columns can use "auto" to preserve the source type, or can be converted to "numeric", "integer", "logical", or "character".


PatientProfiles documentation built on Aug. 22, 2026, 1:07 a.m.