addConceptName: Add concept name for each concept_id

View source: R/utilities.R

addConceptNameR Documentation

Add concept name for each concept_id

Description

Add concept name for each concept_id

Usage

addConceptName(table, column = NULL, nameStyle = "{column}_name")

Arguments

table

cdm_table that contains column.

column

Column to add the concept names from. If NULL any column that its name ends with concept_id will be used.

nameStyle

Name of the new column.

Value

table with an extra column with the concept names.

Examples


library(PatientProfiles)
library(omock)
library(dplyr, warn.conflicts = FALSE)

cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")

cdm$drug_exposure |>
  addConceptName(column = "drug_concept_id", nameStyle = "drug_name") |>
  glimpse()

cdm$drug_exposure |>
  addConceptName() |>
  glimpse()



PatientProfiles documentation built on Feb. 24, 2026, 5:10 p.m.