View source: R/addDemographics.R
| addDateOfBirth | R Documentation |
Add a column with the individual birth date
addDateOfBirth(
x,
dateOfBirthName = "date_of_birth",
missingDay = 1,
missingMonth = 1,
imposeDay = FALSE,
imposeMonth = FALSE,
name = NULL
)
x |
Table with individuals in the cdm. |
dateOfBirthName |
dateOfBirth column name. |
missingDay |
day of the month assigned to individuals with missing day of birth. |
missingMonth |
Month of the year assigned to individuals with missing month of birth. |
imposeDay |
TRUE or FALSE. Whether the day of the date of birth will be considered as missing for all the individuals. |
imposeMonth |
TRUE or FALSE. Whether the month of the date of birth will be considered as missing for all the individuals. |
name |
Name of the new table, if NULL a temporary table is returned. |
The function returns the table x with an extra column that contains the date of birth.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addDateOfBirth()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.