View source: R/addDemographicsQuery.R
| addDateOfBirthQuery | R Documentation |
Same as addDateOfBirth(), except query is not computed to a table.
addDateOfBirthQuery(
x,
dateOfBirthName = "date_of_birth",
missingDay = 1,
missingMonth = 1,
imposeDay = FALSE,
imposeMonth = FALSE
)
x |
Table with individuals in the cdm. |
dateOfBirthName |
dateOfBirth column name. |
missingDay |
day of the month assigned to individuals with missing day of birth. |
missingMonth |
Month of the year assigned to individuals with missing month of birth. |
imposeDay |
TRUE or FALSE. Whether the day of the date of birth will be considered as missing for all the individuals. |
imposeMonth |
TRUE or FALSE. Whether the month of the date of birth will be considered as missing for all the individuals. |
The function returns the table x with an extra column that contains the date of birth.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addDateOfBirthQuery()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.