View source: R/addDemographicsQuery.R
| addFutureObservationQuery | R Documentation |
Same as addFutureObservation(), except query is not computed to a table.
addFutureObservationQuery(
x,
indexDate = "cohort_start_date",
futureObservationName = "future_observation",
futureObservationType = "days"
)
x |
Table with individuals in the cdm. |
indexDate |
Variable in x that contains the date to compute the demographics characteristics. |
futureObservationName |
Future observation variable name. |
futureObservationType |
Whether to return a "date" or the number of "days". |
cohort table with added column containing future observation of the individuals.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addFutureObservationQuery()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.