View source: R/addDemographicsQuery.R
| addPriorObservationQuery | R Documentation |
Same as addPriorObservation(), except query is not computed to a table.
addPriorObservationQuery(
x,
indexDate = "cohort_start_date",
priorObservationName = "prior_observation",
priorObservationType = "days"
)
x |
Table with individuals in the cdm. |
indexDate |
Variable in x that contains the date to compute the demographics characteristics. |
priorObservationName |
Prior observation variable name. |
priorObservationType |
Whether to return a "date" or the number of "days". |
cohort table with added column containing prior observation of the individuals.
library(PatientProfiles)
cdm <- mockPatientProfiles(source = "duckdb")
cdm$cohort1 |>
addPriorObservationQuery()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.