View source: R/filterInObservation.R
| filterInObservation | R Documentation |
cdm_table to the ones in observation that indexDate
is in observation.Filter the rows of a cdm_table to the ones in observation that indexDate
is in observation.
filterInObservation(x, indexDate)
x |
A |
indexDate |
Name of a column of x that is a date. |
A cdm_table that is a subset of the original table.
## Not run:
library(PatientProfiles)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
cdm$condition_occurrence |>
filterInObservation(indexDate = "condition_start_date")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.