It creates a mock database for testing PatientProfiles package
Source:R/mockPatientProfiles.R
mockPatientProfiles.RdIt creates a mock database for testing PatientProfiles package
Usage
mockPatientProfiles(
numberIndividuals = 10,
...,
source = "local",
con = lifecycle::deprecated(),
writeSchema = lifecycle::deprecated(),
seed = lifecycle::deprecated()
)Arguments
- numberIndividuals
Number of individuals to create in the cdm reference.
- ...
User self defined tables to put in cdm, it can input as many as the user want.
- source
Source for the mock cdm, it can either be 'local' or 'duckdb'. By default, vocabulary tables are populated from the GiBleed mock vocabulary provided by omock. A user-provided
concepttable takes precedence.- con
deprecated.
- writeSchema
deprecated.
- seed
deprecated.
Examples
# \donttest{
library(PatientProfiles)
cdm <- mockPatientProfiles()
# }